# -*- coding: utf-8 -*-
import requests
import netifaces
import json
import subprocess

from pppoe_manager import PPPoeManager  # 导入之前封装的 PPPoeManager 类

def get_hostname():
    try:
        with open('/etc/hostname', 'r') as file:
            return file.read().strip()
    except FileNotFoundError:
        print("未找到主机名文件 '/etc/hostname'")
        return ""
# 读取 /opt/pppoe/pppoe_user.txt 文件，并计算文件中行数
def count_lines(file_path):
    try:
        with open(file_path, 'r') as file:
            return sum(1 for line in file)
    except FileNotFoundError:
        print(f"文件 '{file_path}' 未找到")
        return 0
# 读取第一行的最后一个字段作为 "band_single" 字段的值
def get_band_single(file_path):
    try:
        with open(file_path, 'r') as file:
            first_line = file.readline().strip()
            # 获取最后一个字段
            last_field = first_line.split()[-1]
            # 转换为整数
            return int(last_field)
    except FileNotFoundError:
        print(f"文件 '{file_path}' 未找到")
        return 0
# 接口信息
#api_url = 'http://service.chxyun.cn/client/node/batchSubmitClient'
api_url = 'http://service.chxyun.cn/client/node/reSubmitClient'

token = 'D8CE01A6B725FCF09C54DF79BABFC7B5'

# 创建 PPPoeManager 对象并获取 PPPoE 数据的 JSON 格式
ppp_manager = PPPoeManager('/opt/pppoe/pppoe_user.txt')
ppp_json = ppp_manager.get_pppoe_json()

# 获取主机名1,作废
#hostname = get_hostname()

# 获取主机名2
hostname = subprocess.check_output("grep -oP '(?<=\\[ssh:)[^\\]]+' /etc/frp/frpc.ini", shell=True).decode().strip()

# 获取主机名3
#hostname = subprocess.check_output("grep '^hostname' /allconf/hostname.conf | awk -F'=' '{print $2}' | xargs", shell=True).decode().strip()

# 获取第一行的最后一个字段作为 "band_single" 字段的值
band_single = get_band_single('/opt/pppoe/pppoe_user.txt')

# 获取 /opt/pppoe/pppoe_user.txt 文件中的行数，并将其作为 "band_num" 字段的值
band_num = count_lines('/opt/pppoe/pppoe_user.txt')

# 调用函数获取ppp接口数量
def get_ppp_interface_count():
    ppp_interfaces = [interface for interface in netifaces.interfaces() if interface.startswith('ppp')]
    return len(ppp_interfaces)

# 调用函数获取ppp接口数量
ppp_interface_count = get_ppp_interface_count()

# 获取第一行的最后一个字段作为 "band_single" 字段的值
band_single = get_band_single('/opt/pppoe/pppoe_user.txt')

# 构造请求数据
submit_data = {
            "band_num": ppp_interface_count,
            "band_single": band_single,
            "dial": json.loads(ppp_json),  # 将 PPPoE 数据的 JSON 字符串解析为 Python 字典并取出 dial
            "net_type": 1,
            "resource_type": 2,
            "deploy_business": "V4内网",
            "mac": hostname,  # 使用主机名作为 MAC 地址
            "charge_way": 114003,
            "business_alias": "K1业务",
            "isp": 1,
            "province_id": 23,
            "city_id": 378,
            "town_id": 2485
}
#print('Submit Data:', submit_data)
formatted_data = json.dumps(submit_data, indent=4)
print('Submit Data:', formatted_data)

# 发送请求
headers = {'Content-Type':'application/json','Authorization':f'Bearer {token}'}
response = requests.post(api_url, headers=headers, json=submit_data)  # 使用 json 参数直接传递 JSON 数据

# 处理响应
if response.status_code == 200:
    print("请求成功")
    print(response.json())
else:
    print(f"请求失败，状态码: {response.status_code}")
    print(response.text)